@@ -49,6 +49,7 @@
           KCOREADER
           KCOWRITER
           KCOCREATE
+          KCOTRUNCATE
           KCONOLOCK
           KCOAUTOSYNC
           ))
@@ -77,10 +78,10 @@
          [nolock (slot-ref self 'nolock)]
          [rwopt  (case rwmode
                    [(:read) KCOREADER]
-                   [(:write) (+ KCOWRITER
+                   [(:write) (+ KCOWRITER KCOCREATE
                                 (if sync KCOAUTOSYNC 0)
                                 (if nolock KCONOLOCK 0))]
-                   [(:create) (+ KCOWRITER KCOCREATE
+                   [(:create) (+ KCOWRITER KCOCREATE KCOTRUNCATE
                                  (if sync KCOAUTOSYNC 0)
                                  (if nolock KCONOLOCK 0))])]
          [db     (kcdbopen path rwopt)])
@@ -259,6 +260,7 @@
  (define-enum KCOREADER)
  (define-enum KCOWRITER)
  (define-enum KCOCREATE)
+ (define-enum KCOTRUNCATE)
  (define-enum KCOAUTOSYNC)
  (define-enum KCONOLOCK)
  )
