@@ -3,6 +3,7 @@
 ;;;
 
 (use gauche.test)
+(use gauche.dictionary)
 
 (test-start "kyotocabinet")
 (use dbm.kyotocabinet)
@@ -113,10 +114,13 @@
          (unwind-protect (dbm-get db "key\0withnull\0")
                          (dbm-close db))))
 
+(test* "dictionary api"
+       1
+       (let1 db (dbm-open <kyotocabinet> :path *db-file* :key-convert #t :value-convert #t)
+         (unwind-protect
+          (dict-get db 'a)
+          (dbm-close db))))
+
 ;; If you don't want `gosh' to exit with nonzero status even if
 ;; test fails, pass #f to :exit-on-failure.
 (test-end :exit-on-failure #t)
-
-
-
-
